# Garder son système à jour

Effectuer ses mises à jour régulièrement est un des meilleurs moyens de protéger ses outils informatiques des cyberattaques. C'est cependant quelque chose qui est souvent négligé ou planifié à une fréquence beaucoup trop faible.

Pour ne pas oublier et garder un système frais et dispos, il est possible de les automatiser, du moins en bonne partie. Néanmoins, pour ce qui est des serveurs web, il faut faire attention parce qu'elles peuvent compromettre la disponibilité des services. Nous recommandons d'envoyer des alertes à l'équipe d'administration.

## Sur GNU/Linux

Sur GNU/Linux, il n'y a pas de mécanisme uniforme pour effectuer les mises à jour. Chaque famille de distribution vient avec son propre système de gestion de paquetages. Mais, pour simplifier les choses, nous en montrons deux : Debian et Arch.

### Debian

Sur Debian, les mises à jour sont effectuées en deux étapes :

- mettre à jour l'index des paquetages
- installer les nouvelles versions disponibles des paquetages

Il est possible de combiner ces deux actions avec cette commande :

```{.bash linenos="true" breaklines="true" tabsize="2" fontsize="\small" bgcolor="turquoisefonce!10!white"}
sudo apt update && sudo apt upgrade
```

Si nous désirons aller plus loin dans l'automatisation, il est envisageable de programmer les mises à jour de sécurité avec *UnattendedUpgrades.* Cet utilitaire permet qu'elles s'effectuent en arrière-plan selon un calendrier précis sans avoir à s'en occuper.

### Arch

Sur Arch, il y a deux systèmes de gestion de paquetages :

- *pacman*, pour ce qui est officiellement supporté. Nous avons déjà vu ce dernier précédemment, car *Pacman* est utilisé dans MSYS2 sur Windows.
- AUR, pour ce qui est développé par la communauté, avec le client *yay*, utilisé avec la même syntaxe que *Pacman*.

Pour mettres à jour son système avec un de ces deux utilitaires, nous employons les commandes suivantes :

```{.bash linenos="true" breaklines="true" tabsize="2" fontsize="\small" bgcolor="turquoisefonce!10!white"}
pacman -Syyu
yay -Syyu
```

## Sur macOS

Il est possible d'activer les mises à jour automatiques dans les préférences de l’App Store. Aussi simple que ça !

## Sur Windows

Sur Windows, il faut installer l'extension *PSWindowsUpdate* à PowerShell. Elle permet d'interagir avec le système de mises à jour de Windows.

Nous pouvons obtenir la liste des mises à jour à effectuer :

```{.powershell linenos="true" breaklines="true" tabsize="2" fontsize="\small" bgcolor="turquoisefonce!10!white"}
Get-WindowsUpdate
```

Et pour les installer, c'est comme suit (les commandes ont le mérite d'être bien dénommées !) :

```{.powershell linenos="true" breaklines="true" tabsize="2" fontsize="\small" bgcolor="turquoisefonce!10!white"}
Install-WindowsUpdate
```

Si nous souhaitons automatiser le tout (sur Windows c'est beaucoup moins risqué, comme les mises à jour ne s'appliquent qu'au système d'exploitation), alors il suffit de forcer à tout accepter et de redémarrer au besoin. C'est important de **planifier les travaux la nuit** dans ce cas !

```{.powershell linenos="true" breaklines="true" tabsize="2" fontsize="\small" bgcolor="turquoisefonce!10!white"}
Get-WindowsUpdate -AcceptAll -Install -AutoReboot
```

Plus qu'à utiliser ce que nous avons vu au chapitre 1 et mettre cette tâche dans le planificateur de tâches !
